# -*- coding: utf-8 -*-
# emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
# vi: set ft=python sts=4 ts=4 sw=4 et:
"""VistaSoft contains Matlab code to perform a variety of analysis on MRI data."""
from .vista import Vnifti2Image, VtoMat



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..dti import DTMetric


def test_DTMetric_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        data_header=dict(
            argstr="-header %s",
            extensions=None,
        ),
        eigen_data=dict(
            argstr="-inputfile %s",
            extensions=None,
            mandatory=True,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputdatatype=dict(
            argstr="-inputdatatype %s",
            usedefault=True,
        ),
        metric=dict(
            argstr="-stat %s",
            mandatory=True,
        ),
        outputdatatype=dict(
            argstr="-outputdatatype %s",
            usedefault=True,
        ),
        outputfile=dict(
            argstr="-outputfile %s",
            extensions=None,
            genfile=True,
        ),
    )
    inputs = DTMetric.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_DTMetric_outputs():
    output_map = dict(
        metric_stats=dict(
            extensions=None,
        ),
    )
    outputs = DTMetric.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Similarity


def test_Similarity_inputs():
    input_map = dict(
        mask1=dict(
            extensions=None,
        ),
        mask2=dict(
            extensions=None,
        ),
        metric=dict(
            usedefault=True,
        ),
        volume1=dict(
            extensions=None,
            mandatory=True,
        ),
        volume2=dict(
            extensions=None,
            mandatory=True,
        ),
    )
    inputs = Similarity.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Similarity_outputs():
    output_map = dict(
        similarity=dict(),
    )
    outputs = Similarity.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..featuredetection import GenerateBrainClippedImage


def test_GenerateBrainClippedImage_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputImg=dict(
            argstr="--inputImg %s",
            extensions=None,
        ),
        inputMsk=dict(
            argstr="--inputMsk %s",
            extensions=None,
        ),
        numberOfThreads=dict(
            argstr="--numberOfThreads %d",
        ),
        outputFileName=dict(
            argstr="--outputFileName %s",
            hash_files=False,
        ),
    )
    inputs = GenerateBrainClippedImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GenerateBrainClippedImage_outputs():
    output_map = dict(
        outputFileName=dict(
            extensions=None,
        ),
    )
    outputs = GenerateBrainClippedImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import TCorrelate


def test_TCorrelate_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="xset",
            name_template="%s_tcorr",
        ),
        outputtype=dict(),
        pearson=dict(
            argstr="-pearson",
        ),
        polort=dict(
            argstr="-polort %d",
        ),
        xset=dict(
            argstr="%s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-2,
        ),
        yset=dict(
            argstr="%s",
            copyfile=False,
            extensions=None,
            mandatory=True,
            position=-1,
        ),
    )
    inputs = TCorrelate.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_TCorrelate_outputs():
    output_map = dict(
        out_file=dict(
            extensions=None,
        ),
    )
    outputs = TCorrelate.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..specialized import BinaryMaskEditorBasedOnLandmarks


def test_BinaryMaskEditorBasedOnLandmarks_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputBinaryVolume=dict(
            argstr="--inputBinaryVolume %s",
            extensions=None,
        ),
        inputLandmarkNames=dict(
            argstr="--inputLandmarkNames %s",
            sep=",",
        ),
        inputLandmarkNamesForObliquePlane=dict(
            argstr="--inputLandmarkNamesForObliquePlane %s",
            sep=",",
        ),
        inputLandmarksFilename=dict(
            argstr="--inputLandmarksFilename %s",
            extensions=None,
        ),
        outputBinaryVolume=dict(
            argstr="--outputBinaryVolume %s",
            hash_files=False,
        ),
        setCutDirectionForLandmark=dict(
            argstr="--setCutDirectionForLandmark %s",
            sep=",",
        ),
        setCutDirectionForObliquePlane=dict(
            argstr="--setCutDirectionForObliquePlane %s",
            sep=",",
        ),
    )
    inputs = BinaryMaskEditorBasedOnLandmarks.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BinaryMaskEditorBasedOnLandmarks_outputs():
    output_map = dict(
        outputBinaryVolume=dict(
            extensions=None,
        ),
    )
    outputs = BinaryMaskEditorBasedOnLandmarks.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# emacs: at the end of the file
# ex: set sts=4 ts=4 sw=4 et:
# ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### #
"""

Stub file for a guaranteed safe import of duecredit constructs:  if duecredit
is not available.

To use it, place it into your project codebase to be imported, e.g. copy as

    cp stub.py /path/tomodule/module/due.py

Note that it might be better to avoid naming it duecredit.py to avoid shadowing
installed duecredit.

Then use in your code as

    from .due import due, Doi, BibTeX

See  https://github.com/duecredit/duecredit/blob/master/README.md for examples.

Origin:     Originally a part of the duecredit
Copyright:  2015-2016  DueCredit developers
License:    BSD-2
"""

__version__ = "0.0.5"


class InactiveDueCreditCollector(object):
    """Just a stub at the Collector which would not do anything"""

    def _donothing(self, *args, **kwargs):
        """Perform no good and no bad"""
        pass

    def dcite(self, *args, **kwargs):
        """If I could cite I would"""

        def nondecorating_decorator(func):
            return func

        return nondecorating_decorator

    cite = load = add = _donothing

    def __repr__(self):
        return "{}()".format(self.__class__.__name__)


def _donothing_func(*args, **kwargs):
    """Perform no good and no bad"""
    pass


try:
    from duecredit import due, BibTeX, Doi, Url

    if "due" in locals() and not hasattr(due, "cite"):
        raise RuntimeError("Imported due lacks .cite. DueCredit is now disabled")
except ImportError:
    # Initiate due stub
    due = InactiveDueCreditCollector()
    BibTeX = Doi = Url = _donothing_func

# Emacs mode definitions
# Local Variables:
# mode: python
# py-indent-offset: 4
# tab-width: 4
# indent-tabs-mode: nil
# End:



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..featuredetection import GenerateTestImage


def test_GenerateTestImage_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputVolume=dict(
            argstr="--inputVolume %s",
            extensions=None,
        ),
        lowerBoundOfOutputVolume=dict(
            argstr="--lowerBoundOfOutputVolume %f",
        ),
        outputVolume=dict(
            argstr="--outputVolume %s",
            hash_files=False,
        ),
        outputVolumeSize=dict(
            argstr="--outputVolumeSize %f",
        ),
        upperBoundOfOutputVolume=dict(
            argstr="--upperBoundOfOutputVolume %f",
        ),
    )
    inputs = GenerateTestImage.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_GenerateTestImage_outputs():
    output_map = dict(
        outputVolume=dict(
            extensions=None,
        ),
    )
    outputs = GenerateTestImage.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..preprocess import CARegister


def test_CARegister_inputs():
    input_map = dict(
        A=dict(
            argstr="-A %d",
        ),
        align=dict(
            argstr="-align-%s",
        ),
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr="%s",
            extensions=None,
            mandatory=True,
            position=-3,
        ),
        invert_and_save=dict(
            argstr="-invert-and-save",
            position=-4,
        ),
        l_files=dict(
            argstr="-l %s",
        ),
        levels=dict(
            argstr="-levels %d",
        ),
        mask=dict(
            argstr="-mask %s",
            extensions=None,
        ),
        no_big_ventricles=dict(
            argstr="-nobigventricles",
        ),
        num_threads=dict(),
        out_file=dict(
            argstr="%s",
            extensions=None,
            genfile=True,
            position=-1,
        ),
        subjects_dir=dict(),
        template=dict(
            argstr="%s",
            extensions=None,
            position=-2,
        ),
        transform=dict(
            argstr="-T %s",
            extensions=None,
        ),
    )
    inputs = CARegister.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_CARegister_outputs():
    output_map = dict(
        out_file=dict(
            extensions=None,
        ),
    )
    outputs = CARegister.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# -*- coding: utf8 -*-
"""Autogenerated file - DO NOT EDIT
If you spot a bug, please report it on the mailing list and/or change the generator."""

from nipype.interfaces.base import (
    CommandLine,
    CommandLineInputSpec,
    SEMLikeCommandLine,
    TraitedSpec,
    File,
    Directory,
    traits,
    isdefined,
    InputMultiPath,
    OutputMultiPath,
)
import os


class LandmarksCompareInputSpec(CommandLineInputSpec):
    inputLandmarkFile1 = File(
        desc="First input landmark file (.fcsv or .wts)",
        exists=True,
        argstr="--inputLandmarkFile1 %s",
    )
    inputLandmarkFile2 = File(
        desc="Second input landmark file (.fcsv or .wts)",
        exists=True,
        argstr="--inputLandmarkFile2 %s",
    )
    tolerance = traits.Float(
        desc="The maximum error (in mm) allowed in each direction of a landmark",
        argstr="--tolerance %f",
    )


class LandmarksCompareOutputSpec(TraitedSpec):
    pass


class LandmarksCompare(SEMLikeCommandLine):
    """title: Compare Fiducials

    category: Testing

    description: Compares two .fcsv or .wts text files and verifies that they are identicle.  Used for testing landmarks files.

    contributor: Ali Ghayoor
    """

    input_spec = LandmarksCompareInputSpec
    output_spec = LandmarksCompareOutputSpec
    _cmd = " LandmarksCompare "
    _outputs_filenames = {}
    _redirect_x = False



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..brainsresample import BRAINSResample


def test_BRAINSResample_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        defaultValue=dict(
            argstr="--defaultValue %f",
        ),
        deformationVolume=dict(
            argstr="--deformationVolume %s",
            extensions=None,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        gridSpacing=dict(
            argstr="--gridSpacing %s",
            sep=",",
        ),
        inputVolume=dict(
            argstr="--inputVolume %s",
            extensions=None,
        ),
        interpolationMode=dict(
            argstr="--interpolationMode %s",
        ),
        inverseTransform=dict(
            argstr="--inverseTransform ",
        ),
        numberOfThreads=dict(
            argstr="--numberOfThreads %d",
        ),
        outputVolume=dict(
            argstr="--outputVolume %s",
            hash_files=False,
        ),
        pixelType=dict(
            argstr="--pixelType %s",
        ),
        referenceVolume=dict(
            argstr="--referenceVolume %s",
            extensions=None,
        ),
        warpTransform=dict(
            argstr="--warpTransform %s",
            extensions=None,
        ),
    )
    inputs = BRAINSResample.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSResample_outputs():
    output_map = dict(
        outputVolume=dict(
            extensions=None,
        ),
    )
    outputs = BRAINSResample.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..base import IdentityInterface


def test_IdentityInterface_inputs():
    input_map = dict()
    inputs = IdentityInterface.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_IdentityInterface_outputs():
    output_map = dict()
    outputs = IdentityInterface.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import WarpPoints


def test_WarpPoints_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        coord_mm=dict(
            argstr="-mm",
            xor=["coord_vox"],
        ),
        coord_vox=dict(
            argstr="-vox",
            xor=["coord_mm"],
        ),
        dest_file=dict(
            argstr="-dest %s",
            extensions=None,
            mandatory=True,
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_coords=dict(
            argstr="%s",
            extensions=None,
            mandatory=True,
            position=-1,
        ),
        out_file=dict(
            extensions=None,
            name_source="in_coords",
            name_template="%s_warped",
            output_name="out_file",
        ),
        src_file=dict(
            argstr="-src %s",
            extensions=None,
            mandatory=True,
        ),
        warp_file=dict(
            argstr="-warp %s",
            extensions=None,
            xor=["xfm_file"],
        ),
        xfm_file=dict(
            argstr="-xfm %s",
            extensions=None,
            xor=["warp_file"],
        ),
    )
    inputs = WarpPoints.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_WarpPoints_outputs():
    output_map = dict(
        out_file=dict(
            extensions=None,
        ),
    )
    outputs = WarpPoints.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import Merge


def test_Merge_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        blurfwhm=dict(
            argstr="-1blur_fwhm %d",
            units="mm",
        ),
        doall=dict(
            argstr="-doall",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_files=dict(
            argstr="%s",
            copyfile=False,
            mandatory=True,
            position=-1,
        ),
        num_threads=dict(
            nohash=True,
            usedefault=True,
        ),
        out_file=dict(
            argstr="-prefix %s",
            extensions=None,
            name_source="in_files",
            name_template="%s_merge",
        ),
        outputtype=dict(),
    )
    inputs = Merge.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_Merge_outputs():
    output_map = dict(
        out_file=dict(
            extensions=None,
        ),
    )
    outputs = Merge.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value



# -*- coding: utf-8 -*-
# -*- coding: utf8 -*-
"""Autogenerated file - DO NOT EDIT
If you spot a bug, please report it on the mailing list and/or change the generator."""

import os

from ..base import (
    CommandLine,
    CommandLineInputSpec,
    SEMLikeCommandLine,
    TraitedSpec,
    File,
    Directory,
    traits,
    isdefined,
    InputMultiPath,
    OutputMultiPath,
)


class GenerateCsfClippedFromClassifiedImageInputSpec(CommandLineInputSpec):
    inputCassifiedVolume = File(
        desc="Required: input tissue label image",
        exists=True,
        argstr="--inputCassifiedVolume %s",
    )
    outputVolume = traits.Either(
        traits.Bool,
        File(),
        hash_files=False,
        desc="Required: output image",
        argstr="--outputVolume %s",
    )


class GenerateCsfClippedFromClassifiedImageOutputSpec(TraitedSpec):
    outputVolume = File(desc="Required: output image", exists=True)


class GenerateCsfClippedFromClassifiedImage(SEMLikeCommandLine):
    """title: GenerateCsfClippedFromClassifiedImage

    category: FeatureCreator

    description: Get the distance from a voxel to the nearest voxel of a given tissue type.

    version: 0.1.0.$Revision: 1 $(alpha)

    documentation-url: http:://www.na-mic.org/

    license: https://www.nitrc.org/svn/brains/BuildScripts/trunk/License.txt

    contributor: This tool was written by Hans J. Johnson.
    """

    input_spec = GenerateCsfClippedFromClassifiedImageInputSpec
    output_spec = GenerateCsfClippedFromClassifiedImageOutputSpec
    _cmd = " GenerateCsfClippedFromClassifiedImage "
    _outputs_filenames = {"outputVolume": "outputVolume.nii"}
    _redirect_x = False
